% Solves the kdv equation u_t = c*u_x, u(0,x) = u0(x).
function u = kdv_spectral(c, u0, niter, deltat)
	N = size(u0,2);

	% Initialize solution.
	u = zeros(niter, N);
	u(1,:) = u0;

	% Runge-Kutta iterations.
	for n = 2:niter
		oldu = u(n-1,:);
		F1 = c*deltat*(spectral_n_derivative(oldu,3));
		F2 = c*deltat*(spectral_n_derivative(oldu+0.5*F1,3));
		F3 = c*deltat*(spectral_n_derivative(oldu+0.5*F2,3));
		F4 = c*deltat*(spectral_n_derivative(oldu+F3,3));
		u(n, :) = oldu + 1/6*(F1 + 2*F2 + 2*F3 + F4);
	end
end