% Solves the wave equation u_t + c*u_x = 0, u(0,x) = u0(x).
function u = wave_spectral(c, u0, niter, deltat)
	N = size(u0,2);

	% Initialize solution.
	u = zeros(niter, N);
	u(1,:) = u0;

	% Runge-Kutta iterations.
	for n = 2:niter
		oldu = u(n-1,:);
		F1 = -c*deltat*(spectral_derivative(oldu));
		F2 = -c*deltat*(spectral_derivative(oldu+0.5*F1));
		F3 = -c*deltat*(spectral_derivative(oldu+0.5*F2));
		F4 = -c*deltat*(spectral_derivative(oldu+F3));
		u(n, :) = oldu + 1/6*(F1 + 2*F2 + 2*F3 + F4);
	end
end