% Solves the wave equation u_t + c*u_x = 0, u(0,x) = u0(x).
function u = wave_spectral1(c, u0, niter, deltat)
	N = size(u0,2);
	
	% Initialize solution.
	v = zeros(niter, N);
	v(1,:) = fftshift(fft(u0));

	% Runge-Kutta iterations.
	for n = 2:niter
		oldv = v(n-1,:);
		F1 = -i*c*deltat*(oldv);
		F2 = -i*c*deltat*(oldv+0.5*F1);
		F3 = -i*c*deltat*(oldv+0.5*F2);
		F4 = -i*c*deltat*(oldv+F3);
		u(n, :) = oldv + 1/6*(F1 + 2*F2 + 2*F3 + F4);
	end
	
	u = zeros(niter, N);
	for j = 1:niter
		u(j,:) = real(ifft(ifftshift(v(j,:))));
	end
end